Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(462)

Unified Diff: net/log/net_log.h

Issue 2351513002: net: rename BoundNetLog to NetLogWithSource (Closed)
Patch Set: one more fix, content bound_net_log_ Created 4 years, 3 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: net/log/net_log.h
diff --git a/net/log/net_log.h b/net/log/net_log.h
index 842116c8ed210c369902f78c64edb3fee64de41a..f637b98cf7e5ccdcba84430c258b59ae89fa9176 100644
--- a/net/log/net_log.h
+++ b/net/log/net_log.h
@@ -37,7 +37,7 @@ namespace net {
// SpdySession).
//
// To avoid needing to pass in the "source ID" to the logging functions, NetLog
// is usually accessed through a BoundNetLog, which will always pass in a
// specific source ID.
//
// All methods are thread safe, with the exception that no NetLog or
@@ -275,7 +275,7 @@ class NET_EXPORT NetLog {
const base::string16* value);
private:
- friend class BoundNetLog;
+ friend class NetLogWithSource;
void AddEntry(NetLogEventType type,
const Source& source,
@@ -305,10 +305,10 @@ class NET_EXPORT NetLog {
// Helper that binds a Source to a NetLog, and exposes convenience methods to
// output log messages without needing to pass in the source.
-class NET_EXPORT BoundNetLog {
+class NET_EXPORT NetLogWithSource {
public:
- BoundNetLog() : net_log_(NULL) {}
- ~BoundNetLog();
+ NetLogWithSource() : net_log_(NULL) {}
+ ~NetLogWithSource();
// Add a log entry to the NetLog for the bound source.
void AddEntry(NetLogEventType type, NetLogEventPhase phase) const;
@@ -352,10 +352,10 @@ class NET_EXPORT BoundNetLog {
bool IsCapturing() const;
// Helper to create a BoundNetLog given a NetLog and a NetLogSourceType.
// Takes care of creating a unique source ID, and handles
// the case of NULL net_log.
- static BoundNetLog Make(NetLog* net_log, NetLogSourceType source_type);
+ static NetLogWithSource Make(NetLog* net_log, NetLogSourceType source_type);
const NetLog::Source& source() const { return source_; }
NetLog* net_log() const { return net_log_; }
@@ -367,7 +367,7 @@ class NET_EXPORT BoundNetLog {
DEAD = 0xDEADBEEF,
};
- BoundNetLog(const NetLog::Source& source, NetLog* net_log)
+ NetLogWithSource(const NetLog::Source& source, NetLog* net_log)
: source_(source), net_log_(net_log) {}
// TODO(eroman): Temporary until crbug.com/467797 is solved.
@@ -37,7 +37,7 @@ namespace net {
//
// To avoid needing to pass in the "source ID" to the logging functions, NetLog
-// is usually accessed through a BoundNetLog, which will always pass in a
+// is usually accessed through a NetLogWithSource, which will always pass in a
// specific source ID.
//
@@ -352,10 +352,10 @@ class NET_EXPORT BoundNetLog {
bool IsCapturing() const;
- // Helper to create a BoundNetLog given a NetLog and a NetLogSourceType.
+ // Helper to create a NetLogWithSource given a NetLog and a NetLogSourceType.
// Takes care of creating a unique source ID, and handles
// the case of NULL net_log.

Powered by Google App Engine
This is Rietveld 408576698